package com.upay.sdk.onlinepay;

import com.alibaba.fastjson15.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.RequestParamException;
import com.upay.sdk.exception.ResponseDecryptException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.member.v_2.builder.SnapshotQueryBuilder;
import com.upay.sdk.member.v_2.executer.MemberSnapshotExecuter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Date;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DayBalanceQuery extends HttpServlet {


    static final Logger LOGGER = LoggerFactory.getLogger(DayBalanceQuery.class);
    private static final long serialVersionUID = -679848935977904231L;

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {

        final String agent = req.getHeader("User-agent");//判断客户端
        LOGGER.info("agent:{}", agent);

        String merchantId = req.getParameter("merchantId");
        final PrintWriter out = resp.getWriter();
        if (StringUtils.isBlank(merchantId)) {
            out.println("参数异常</br>");
            out.println("商户编号不能为空");
            return;
        } else {
            if (merchantId.length() != 9) {
                out.println("参数异常</br>");
                out.println("商户编号长度必须为9");
                return;
            }
        }
        //查询日期
        String snapshotDate = req.getParameter("snapshotDate");
        //币种
        String currency = req.getParameter("currency");
        //账户类型
        String queryAccountType = req.getParameter("queryAccountType");
        //服务商id
        String partnerId = req.getParameter("partnerId");
        //时间戳
        //String requestTime = req.getParameter("requestTime");
        String requestTime = requestTime = DateFormatUtils.format(new Date(), "yyyy-MM-dd HH:mm:ss");

        SnapshotQueryBuilder builder = new SnapshotQueryBuilder();
        builder.setMerchantId(merchantId);
        builder.setCurrency(currency);
        builder.setRequestTime(requestTime);
        builder.setQueryAccountType(queryAccountType);
        builder.setSnapshotDate(snapshotDate);

        builder.setPartnerId(partnerId);

        try {
            MemberSnapshotExecuter executer = new MemberSnapshotExecuter();
            executer.queryMemberSnapshot(builder, new ResultListenerAdpater() {
                @Override
                public void success(JSONObject jsonObject) {
                    out.println("处理成功！<br/>");
                    String result = jsonObject.toJSONString();
                    out.print(result);
                }

                @Override
                public void failure(JSONObject jsonObject) {
                    out.println("处理失败！<br/>");
                    String result = jsonObject.toJSONString();
                    out.print(result);
                }

                @Override
                public void pending(JSONObject jsonObject) {
                    out.println("待处理！<br/>");
                    String result = jsonObject.toJSONString();
                    out.print(result);
                }
            });
        } catch (ResponseException e) {
            out.println("响应异常</br>");
            out.println(e.toString());
        } catch (HmacVerifyException e) {
            out.println("签名验证异常</br>");
            out.println(e.toString());
        } catch (RequestException e) {
            out.println("请求异常</br>");
            out.println(e.toString());
        } catch (UnknownException | RequestParamException | ResponseDecryptException e) {
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}
